#!/usr/bin/perl

# eGuideDog - voice web browser for the vissual impairred
#
# Author: Cameron Wong (http://eguidedog.sf.net)
# License: GPL v2

use strict;
use warnings;
use Getopt::Long;
use eGuideDog::Browser;
use eGuideDog::Speaker;
use eGuideDog::Helper;
use eGuideDog::Terminal;
use eGuideDog::Browser::Const;
#use Curses; # This is for key mapping. It's not good to port it to Windows.

sub usage() {
  print <<END_USAGE;

eGuideDog voice web browser

Usage: perl e-guidedog [options] [url]

options:
  -html           Show raw html DOM tree of the page.
  -lang           Run with specified language.
  -mute           Run with no sound.
  -help           Show this help message.

some using example:

#./e-guidedog

#./e-guidedog --help

#./e-guidedog e-guidedog.sourceforge.net

AUTHOR
Cameron Wong (http://e-guidedog.sf.net)

END_USAGE

  exit;
}

my %options;
usage() unless GetOptions(\%options,
			  'url=s',
			  'lang=s',
			  'mute',
			  'html',
			  'text',
			  'filter',
			  'control',
			  'summarize',
			  'help',
			  'terminal=s',
			  'tts=s',
			  'try');
usage() if ($options{help});

# init speaker
my $speaker = eGuideDog::Speaker->new('eSpeak');
if ($options{mute}) {
  $speaker->mute();
}
if ($options{lang}) {
  $speaker->language($options{lang});
}

# init browser
my $browser;
$options{url} = shift if (!$options{url});
if ($options{url}) {
  $browser = eGuideDog::Browser->new($options{url});
} else {
  $browser = eGuideDog::Browser->new();
}
$browser->speaker($speaker);

# constant reference
my $c = eGuideDog::Browser::Const::new();

# init terminal
my $terminal = eGuideDog::Terminal->new();
$terminal->print_buffer($browser->screen);


my $result;
do {
  $result = $browser->press($terminal->readkey());
  my $command = $browser->command;
  if ($command) {
    if ($command == $c->AUTO_SPEAK) {
      if (not $speaker->is_playing()) {
	$result = $browser->press($c->KEYS_DOWN);
      }
    }
  }

  my $speech = $browser->speech;
  if ($speech) {
    $speaker->stop();
    $speaker->speak($speech);
  }

  $terminal->print_buffer($browser->screen);
} until ($result == eGuideDog::Browser::Const::EXIT);
